# mdai-client-py

MD.ai Python Client Library

**Currently pre-alpha -- API may change significantly in future releases.**

The python client library is designed to work with the datasets generated by the [Md.ai](https://www.md.ai/) Medical AI platform.

You can download datasets consisting of images and annotations, create train/validation/test datasets, integrate with various machine learing libraries (e.g., TensorFlow/Keras, Fast.ai) for developing machine learning algorithms.

To get started, check out the examples in the [notebooks section](notebooks).

## Installation

Install and update using [pip](https://pip.pypa.io/en/stable/quickstart/):

```sh
pip install --upgrade mdai
```

## Example Notebooks

[HelloWorld Keras Notebook](notebooks/hello-world-keras.ipynb)

[HelloWorld TFRecords Notebook](notebooks/hello-world-tfrecords-VGG16.ipynb)

[HelloWorld Fast.ai](notebooks/hello-world-fastai.ipynb)


## API Documentation
Coming soon.

## Contributing

See [contributing guidelines](CONTRIBUTING.md) to set up a development environemnt and how to make contributions to mdai.

---

&copy; 2018 MD.ai, Inc.
